textify_p <- function(p){
  ## This function takes a numeric P value
  ## and returns a corresponding text string
  ## ... as P<0.01, etc
  if(length(p)==0) return(NA)
  if (class(p)=="numeric") {
    return(
      cut(p,
          breaks=c(-Inf, 0.0001, 0.001, 0.01, 0.05, 1),
          labels=c("$P<0.0001$", "$P<0.001$", "$P<0.01$", "$P<0.05$", "$P\\ge0.05$")
      )
    )
  }
}

textify_p_stars <- function(p){
  ## This function takes a numeric P value
  ## and returns a corresponding text string
  ## ... as ** for P<0.01, etc
  if(length(p)==0) return(NA)
  if (class(p)=="numeric") {
    return(
      cut(p,
          breaks=c(-Inf, 0.0001, 0.001, 0.01, 0.05, 1),
          labels=c("****", "***", "**", "*", "ns")
      )
    )
  }
}

numbers2words <- function(x, capFirst=FALSE){
  ## This function takes a numeric/integer and returns a text
  ## string with the number in plain English
  ## ... e.g. 101 as "one hundred and one" 
  
  ## Function by John Fox found here: 
  ## http://tolstoy.newcastle.edu.au/R/help/05/04/2715.html
  ## Tweaks by AJH to add commas and "and"
  helper <- function(x){
    
    digits <- rev(strsplit(as.character(x), "")[[1]])
    nDigits <- length(digits)
    if (nDigits == 1) as.vector(ones[digits])
    else if (nDigits == 2)
      if (x <= 19) as.vector(teens[digits[1]])
    else trim(paste(tens[digits[2]],
                    Recall(as.numeric(digits[1]))))
    else if (nDigits == 3) trim(paste(ones[digits[3]], "hundred and", 
                                      Recall(makeNumber(digits[2:1]))))
    else {
      nSuffix <- ((nDigits + 2) %/% 3) - 1
      if (nSuffix > length(suffixes)) stop(paste(x, "is too large!"))
      trim(paste(Recall(makeNumber(digits[
        nDigits:(3*nSuffix + 1)])),
        suffixes[nSuffix],"," ,
        Recall(makeNumber(digits[(3*nSuffix):1]))))
    }
  }
  trim <- function(text){
    #Tidy leading/trailing whitespace, space before comma
    text=gsub("^\ ", "", gsub("\ *$", "", gsub("\ ,",",",text)))
    #Clear any trailing " and"
    text=gsub(" and$","",text)
    #Clear any trailing comma
    gsub("\ *,$","",text)
  }  
  makeNumber <- function(...) as.numeric(paste(..., collapse=""))     
  #Disable scientific notation
  opts <- options(scipen=100) 
  on.exit(options(opts)) 
  ones <- c("", "one", "two", "three", "four", "five", "six", "seven",
            "eight", "nine") 
  names(ones) <- 0:9 
  teens <- c("ten", "eleven", "twelve", "thirteen", "fourteen", "fifteen",
             "sixteen", " seventeen", "eighteen", "nineteen")
  names(teens) <- 0:9 
  tens <- c("twenty", "thirty", "forty", "fifty", "sixty", "seventy", "eighty",
            "ninety") 
  names(tens) <- 2:9 
  x <- round(x)
  suffixes <- c("thousand", "million", "billion", "trillion")     
  if (length(x) > 1) return(trim(sapply(x, helper)))
  helper(x)
}

cap_first <- function(t) {
  ## This function takes a text string and returns it
  ## with the first letter capitalized.
  if (t!="") {
    return(paste(toupper(substr(t,1,1)), substr(t, 2, nchar(t)), sep=""))
  }
}
