# This script is sourced by the main.R script.

# It generates a random set of dummy data and
# stores it to a csv and excel file in the data
# folder

# The aim is to provide a simulated 'real'
# data set for loading, cleaning, etc

library(tidyverse)

# Generate data set ----
n = 200 # Number of observations to generate
# Generate some CPR numbers
data_experimental <- tibble(
  cpr = str_c(
    sample(seq(as.Date('1970/01/01'), as.Date('2020/12/31'), by="day"), n, replace=TRUE) %>% format(., "%d%m%y"),
    "-",
    sample(1000:9999, n, replace=TRUE)
    )
  )

# Add some dummy experimental data ----
data_experimental <- data_experimental %>%
  mutate(tester = sample(LETTERS[1:3], n, replace=TRUE)) %>%
  mutate(intervention = sample(c("x","y","z"), n, replace=TRUE)) %>%
  mutate(measurement = sample(rnorm(n, 11, 25)))

# Now shift measurements for two of the interventions ----
data_experimental <- data_experimental %>%
  mutate(measurement = case_when(
    intervention == "x" ~ measurement - 15,
    intervention == "y" ~ measurement,
    intervention == "z" ~ measurement + 13
  ))

# Generate some dummy clinical data ----
data_clinical <- data_experimental %>%
  select(cpr) %>%
  mutate(severity = sample(0:10, n, replace=TRUE)) %>%
  mutate(duration = sample(8:121, n, replace=TRUE))

# Make some bad data ----
n_bad_data = round(n * .05)
# Put NA measurements in experimental data
data_experimental[sample(1:n, n_bad_data, replace=FALSE),'measurement'] <- NA
# Mess with some CPR numbers in clinical data by removing the hyphen
if (n>30) {
  data_clinical[11, 'cpr'] <- str_replace(data_clinical[11, 'cpr'], "-", "")
  data_clinical[21, 'cpr'] <- str_replace(data_clinical[21, 'cpr'], "-", "")
  data_clinical[30, 'cpr'] <- str_replace(data_clinical[30, 'cpr'], "-", "")
}

write.csv2(data_experimental, "data/raw_exp_data.csv")
write.csv2(data_clinical, "data/raw_clin_data.csv")


